#!/bin/bash
# http://www.vamp-plugins.org/
# svn co https://vamp.svn.sourceforge.net/svnroot/vamp vamp
#
# Queen Mary, University of London, Centre for Digital Music
QM_VAMP=qm-vamp-plugins-1.6-i686-linux.tar.gz
QM_URL=http://isophonics.net/files/

# Mazurka Project Plugins for Sonic Visualiser
# http://www.mazurka.org.uk/software/sv/plugin/download/linux/mazurka-plugins.so

# script: til <rob DOT til DOT freedman AT googlemail DOT com>
#
set -e -x

# vamp-plugin-sdk
version="2.1"
BUILD=${BUILD:-64.1}
ARCH=${ARCH:-i486}
CPU=${CPU:-i686}

pkgname=vamp-plugin-sdk-$version
package=$pkgname-$ARCH-$BUILD

#
PKG_DEP="cxxlibs,flac,libogg,libsndfile"
#
#http://dfn.dl.sourceforge.net/project/vamp/vamp-plugin-sdk/2.1/vamp-plugin-sdk-2.1-docs.zip
#
PKG_SRC="http://dfn.dl.sourceforge.net/project/vamp/vamp-plugin-sdk/${version}/vamp-plugin-sdk-${version}.tar.gz
http://zenwalk.pinguix.com/user-accounts/tilderb/extra/vamp/build-vamp-plugin-sdk.sh"
#
# build directory
CWD=`pwd`
TMP=${TMP:-$CWD}
SRC=$TMP/$pkgname
PKG=$TMP/$package

[ -d $PKG ] && rm -fr $PKG
[ -d $SRC ] && rm -fr $SRC

# prepare build directory
mkdir -p $PKG/{install,usr/{src,doc}/$pkgname}
mkdir -p $PKG/usr/lib/vamp
mkdir -p $SRC

tar xzf $CWD/$pkgname.tar.gz --strip-components=1 -C $SRC || exit 1
cd $SRC

CFLAGS="-O2 -march=$ARCH -mtune=$CPU" \
CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU" \
  ./configure --prefix=/usr

make || exit 1
make install DESTDIR=$PKG

# copy example plugins
cp -a examples/vamp-example-plugins.*  $PKG/usr/lib/vamp
cp -a COPYING README README.compat build/README.linux  $PKG/usr/doc/$pkgname

# strip symbols
find $PKG | xargs file | grep -e "executable" -e "shared object" | grep ELF | \
	cut -s -f 1 -d : | xargs -r strip --strip-unneeded 2> /dev/null

find $PKG | xargs file | grep "current ar archive" | \
	cut -s -f 1 -d : | xargs -r strip -g 2> /dev/null

# Queen Mary, University of London, Centre for Digital Music
if [ -e $CWD/${QM_VAMP} ]; then
 tar xf $CWD/${QM_VAMP} -C $PKG/usr/doc/$pkgname/ --strip-components=1 --exclude="qm-vamp-plugins.*"  --xform="s:\.txt:.qm_vamp.txt:g"
 tar xf $CWD/${QM_VAMP} -C $PKG/usr/lib/vamp/ --strip-components=1 --exclude="*.txt"
fi

# Mazurka Project Plugins
if [ -e $CWD/mazurka-plugins.so ]; then
 cp $CWD/mazurka-plugins.so $PKG/usr/lib/vamp
 echo "http://www.mazurka.org.uk" >$PKG/usr/doc/$pkgname/README.mazurka-plugins
fi

#
# slack description
#              |-----handy-ruler------------------------------------------------------|
cat <<EOF > $PKG/install/slack-desc
vamp-plugin-sdk: vamp-plugin-sdk (Vamp is an audio processing plugin system)
vamp-plugin-sdk:
vamp-plugin-sdk: Vamp is an audio processing plugin system for plugins 
vamp-plugin-sdk: that extract descriptive information from audio data
vamp-plugin-sdk: typically referred to as audio analysis plugins or
vamp-plugin-sdk: audio feature extraction plugins.
vamp-plugin-sdk:
EOF
# copy build script
cp $CWD/build-vamp-plugin-sdk.sh $PKG/usr/src/$pkgname

# create package
cd $PKG
fakeroot /sbin/makepkg -l y -c n $CWD/$package.txz

cd $CWD
#requiredbuilder -z $PKG
echo $PKG_DEP >$package.dep
echo "$PKG_SRC" >$package.src
md5sum $package.tgz >$package.md5
